@@ -2,7 +2,7 @@
 !   Nathaniel E. Helwig (helwig@umn.edu)
 !   Department of Psychology and School of Statistics
 !   University of Minnesota
-!   Date: 2023-11-01
+!   Date: 2024-06-26
 
 
 ! INPUTS/OUTPUTS
@@ -68,7 +68,7 @@ SUBROUTINE grpnet_negbin(nobs, nvars, x, y, w, off, ngrps, gsize, pw, alpha, &
     DOUBLE PRECISION zvec(nvars), grad(nvars), gradnorm(ngrps)
     DOUBLE PRECISION ctol, shrink, twolam, penone, pentwo, xmean(nvars)
     DOUBLE PRECISION xsdev(ngrps), xev(ngrps), znorm, bnorm
-    DOUBLE PRECISION eta(nobs), mu(nobs), vmax
+    DOUBLE PRECISION eta(nobs), mu(nobs), vmax, ymax
     DOUBLE PRECISION, ALLOCATABLE :: xtx(:,:)
 ! --------------- LOCAL DEFINITIONS --------------- !
 
@@ -158,6 +158,7 @@ SUBROUTINE grpnet_negbin(nobs, nvars, x, y, w, off, ngrps, gsize, pw, alpha, &
     eta = off
     mu = EXP(eta)
     r = w * (y - mu) / (1.0D0 + mu/theta)
+    ymax = MAXVAL(y / (1.0D0 + y / theta))
 ! --------------- MISCELLANEOUS INITIALIZATIONS --------------- !
 
 
@@ -186,12 +187,7 @@ SUBROUTINE grpnet_negbin(nobs, nvars, x, y, w, off, ngrps, gsize, pw, alpha, &
                 iter = iter + 1
 
                 ! update vmax
-                IF (iter == 1) THEN
-                    vmax = MAX(MAXVAL( mu / (1.0D0 + mu / theta) ), &
-                               MAXVAL( y / (1.0D0 + y / theta) ))
-                ELSE
-                    vmax = MAXVAL( mu / (1.0D0 + mu / theta) )
-                END IF
+                vmax = MAX(MAXVAL( mu / (1.0D0 + mu / theta) ), ymax)
 
                 ! update active groups
                 DO k=1,ngrps
@@ -318,7 +314,7 @@ SUBROUTINE grpnet_negbin(nobs, nvars, x, y, w, off, ngrps, gsize, pw, alpha, &
                     ctol = 0.0D0
 
                     ! update vmax
-                    vmax = MAXVAL(mu / (1.0D0 + mu / theta))
+                    vmax = MAX(MAXVAL(mu / (1.0D0 + mu / theta)), ymax)
 
                     ! unweighted or weighted update?
                     IF (weighted == 0) THEN
@@ -490,7 +486,7 @@ SUBROUTINE grpnet_negbin_dev(nobs, y, mu, wt, theta, dev)
     dev = 0.0D0
     DO i=1,nobs
         IF (y(i) > 0) THEN
-            dev = dev + 2.0D0 * wt(i) * ( y(i) * log(y(i) / mu(i)) )
+            dev = dev + 2.0D0 * wt(i) * y(i) * log(y(i) / mu(i))
         END IF
     END DO
     dev = dev - 2.0D0 * SUM( wt * (y + theta) * log((y + theta) / (mu + theta)) )
